@@ -5,12 +5,12 @@ built_modules = list(name for name in
 shiboken_library_soversion = str(5.15)
 pyside_library_soversion = str(5.15)
 
-version = "5.15.13"
-version_info = (5, 15, 13, "", "")
-
-__build_date__ = '2024-05-11T11:28:16+00:00'
-
+version = "5.15.16"
+version_info = (5, 15, 16, "", "")
 
+__build_date__ = '2025-07-27T20:28:10+00:00'
+__build_commit_date__ = '2025-07-24T19:10:19+00:00'
+__build_commit_hash__ = '50c5d7b0badea6b84beb5e5e7210c27b7c36f6a4'
 
 
 
